@@ -13,7 +13,6 @@
 #' @export
 #'
 #' @examples
-#' library(starschemar)
 #'
 #' gms <- geomultistar(ms = ms_mrs, geodimension = "where") |>
 #'   define_geoattribute(
@@ -47,14 +46,17 @@
 #'
 #' sf <- gdq |>
 #'   run_geoquery(wider = TRUE)
-#'\donttest{
+#'
 #' save_as_geopackage(sf, "city", filepath = tempdir())
-#'}
+#'
 save_as_geopackage <- function(sf, layer_name, file_name = NULL, filepath = NULL) {
   if (is.null(file_name)) {
     file_name <- layer_name
   }
-  filepath <- paste(filepath, file_name, ".gpkg", sep = "")
+  if (!is.null(filepath)) {
+    filepath <- name_with_nexus(filepath)
+  }
+  filepath <- paste0(filepath, file_name, ".gpkg")
   if (is.list(sf)) {
     sf::st_write(sf$sf, filepath, layer = layer_name, append = FALSE, delete_dsn = TRUE, driver = 'GPKG')
     if (length(sf) > 1) {
@@ -67,6 +69,3 @@ save_as_geopackage <- function(sf, layer_name, file_name = NULL, filepath = NULL
   }
   sf
 }
-
-
-
